Documentation
¶
Overview ¶
Package snowflake provides functions for acting on Discord snowflakes.
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Timestamp ¶
Timestamp will return the timestamp embedded in a snowflake. Failure to parse the snowflake will result in the current time being returned.
Example ¶
package main
import (
"fmt"
"bitbucket.org/idomdavis/discordance/snowflake"
)
func main() {
fmt.Println(snowflake.Timestamp("943865945699532811").Unix())
}
Output: 1645105577
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.